@@ -1,9 +1,12 @@
 package Net::Amazon::S3::Bucket;
-use Moose;
-use MooseX::StrictConstructor;
+{
+  $Net::Amazon::S3::Bucket::VERSION = '0.57';
+}
+use Moose 0.85;
+use MooseX::StrictConstructor 0.16;
 use Carp;
 use File::stat;
-use IO::File;
+use IO::File 1.14;
 
 has 'account' => ( is => 'ro', isa => 'Net::Amazon::S3', required => 1 );
 has 'bucket'  => ( is => 'ro', isa => 'Str',             required => 1 );
@@ -11,72 +14,8 @@ has 'creation_date' => ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
 
 __PACKAGE__->meta->make_immutable;
 
-=head1 NAME
+# ABSTRACT: convenience object for working with Amazon S3 buckets
 
-Net::Amazon::S3::Bucket - convenience object for working with Amazon S3 buckets
-
-=head1 SYNOPSIS
-
-  use Net::Amazon::S3;
-
-  my $bucket = $s3->bucket("foo");
-
-  ok($bucket->add_key("key", "data"));
-  ok($bucket->add_key("key", "data", {
-     content_type => "text/html",
-    'x-amz-meta-colour' => 'orange',
-  });
-
-  # the err and errstr methods just proxy up to the Net::Amazon::S3's
-  # objects err/errstr methods.
-  $bucket->add_key("bar", "baz") or
-      die $bucket->err . $bucket->errstr;
-
-  # fetch a key
-  $val = $bucket->get_key("key");
-  is( $val->{value},               'data' );
-  is( $val->{content_type},        'text/html' );
-  is( $val->{etag},                'b9ece18c950afbfa6b0fdbfa4ff731d3' );
-  is( $val->{'x-amz-meta-colour'}, 'orange' );
-
-  # returns undef on missing or on error (check $bucket->err)
-  is(undef, $bucket->get_key("non-existing-key"));
-  die $bucket->errstr if $bucket->err;
-
-  # fetch a key's metadata
-  $val = $bucket->head_key("key");
-  is( $val->{value},               '' );
-  is( $val->{content_type},        'text/html' );
-  is( $val->{etag},                'b9ece18c950afbfa6b0fdbfa4ff731d3' );
-  is( $val->{'x-amz-meta-colour'}, 'orange' );
-
-  # delete a key
-  ok($bucket->delete_key($key_name));
-  ok(! $bucket->delete_key("non-exist-key"));
-
-  # delete the entire bucket (Amazon requires it first be empty)
-  $bucket->delete_bucket;
- 
-=head1 DESCRIPTION
-
-This module represents an S3 bucket.  You get a bucket object
-from the Net::Amazon::S3 object.
-
-=head1 METHODS
-
-=head2 new
-
-Create a new bucket object. Expects a hash containing these two arguments:
-
-=over
-
-=item bucket
-
-=item account
-
-=back
-
-=cut
 
 sub _uri {
     my ( $self, $key ) = @_;
@@ -99,25 +38,6 @@ sub _conf_to_headers {
     return $conf;
 }
 
-=head2 add_key
-
-Takes three positional parameters:
-
-=over
-
-=item key
-
-=item value
-
-=item configuration
-
-A hash of configuration data for this key. (See synopsis);
-
-=back
-
-Returns a boolean.
-
-=cut
 
 # returns bool
 sub add_key {
@@ -156,55 +76,12 @@ sub add_key {
     }
 }
 
-=head2 add_key_filename
-
-Use this to upload a large file to S3. Takes three positional parameters:
-
-=over
-
-=item key
-
-=item filename
-
-=item configuration
-
-A hash of configuration data for this key. (See synopsis);
-
-=back
-
-Returns a boolean.
-
-=cut
 
 sub add_key_filename {
     my ( $self, $key, $value, $conf ) = @_;
     return $self->add_key( $key, \$value, $conf );
 }
 
-=head2 copy_key
-
-Creates (or replaces) a key, copying its contents from another key elsewhere in S3.
-Takes the following parameters:
-
-=over
-
-=item key
-
-The key to (over)write
-
-=item source
-
-Where to copy the key from. Should be in the form C</I<bucketname>/I<keyname>>/.
-
-=item conf
-
-Optional configuration hash. If present and defined, the configuration (ACL
-and headers) there will be used for the new key; otherwise it will be copied
-from the source key.
-
-=back
-
-=cut
 
 sub copy_key {
     my ( $self, $key, $source, $conf ) = @_;
@@ -243,23 +120,6 @@ sub copy_key {
     return 1;
 }
 
-=head2 edit_metadata
-
-Changes the metadata associated with an existing key. Arguments:
-
-=over
-
-=item key
-
-The key to edit
-
-=item conf
-
-The new configuration hash to use
-
-=back
-
-=cut
 
 sub edit_metadata {
     my ( $self, $key, $conf ) = @_;
@@ -268,32 +128,12 @@ sub edit_metadata {
     return $self->copy_key( $key, "/" . $self->bucket . "/" . $key, $conf );
 }
 
-=head2 head_key KEY
-
-Takes the name of a key in this bucket and returns its configuration hash
-
-=cut
 
 sub head_key {
     my ( $self, $key ) = @_;
     return $self->get_key( $key, "HEAD" );
 }
 
-=head2 get_key $key_name [$method]
-
-Takes a key name and an optional HTTP method (which defaults to C<GET>.
-Fetches the key from AWS.
-
-On failure:
-
-Returns undef on missing content, throws an exception (dies) on server errors.
-
-On success:
-
-Returns a hashref of { content_type, etag, value, @meta } on success. Other
-values from the server are there too, with the key being lowercased.
-
-=cut
 
 sub get_key {
     my ( $self, $key, $method, $filename ) = @_;
@@ -334,34 +174,12 @@ sub get_key {
 
 }
 
-=head2 get_key_filename $key_name $method $filename
-
-Use this to download large files from S3. Takes a key name and an optional 
-HTTP method (which defaults to C<GET>. Fetches the key from AWS and writes
-it to the filename. THe value returned will be empty.
-
-On failure:
-
-Returns undef on missing content, throws an exception (dies) on server errors.
-
-On success:
-
-Returns a hashref of { content_type, etag, value, @meta } on success
-
-=cut
 
 sub get_key_filename {
     my ( $self, $key, $method, $filename ) = @_;
     return $self->get_key( $key, $method, \$filename );
 }
 
-=head2 delete_key $key_name
-
-Removes C<$key> from the bucket. Forever. It's gone after this.
-
-Returns true on success and false on failure
-
-=cut
 
 # returns bool
 sub delete_key {
@@ -377,15 +195,6 @@ sub delete_key {
     return $self->account->_send_request_expect_nothing($http_request);
 }
 
-=head2 delete_bucket
-
-Delete the current bucket object from the server. Takes no arguments. 
-
-Fails if the bucket has anything in it.
-
-This is an alias for C<< $s3->delete_bucket($bucket) >>
-
-=cut
 
 sub delete_bucket {
     my $self = shift;
@@ -393,13 +202,6 @@ sub delete_bucket {
     return $self->account->delete_bucket($self);
 }
 
-=head2 list
-
-List all keys in this bucket.
-
-see L<Net::Amazon::S3/list_bucket> for documentation of this method.
-
-=cut
 
 sub list {
     my $self = shift;
@@ -408,14 +210,6 @@ sub list {
     return $self->account->list_bucket($conf);
 }
 
-=head2 list_all
-
-List all keys in this bucket without having to worry about
-'marker'. This may make multiple requests to S3 under the hood.
-
-see L<Net::Amazon::S3/list_bucket_all> for documentation of this method.
-
-=cut
 
 sub list_all {
     my $self = shift;
@@ -424,21 +218,6 @@ sub list_all {
     return $self->account->list_bucket_all($conf);
 }
 
-=head2 get_acl
-
-Takes one optional positional parameter
-
-=over
-
-=item key (optional)
-
-If no key is specified, it returns the acl for the bucket.
-
-=back
-
-Returns an acl in XML format.
-
-=cut
 
 sub get_acl {
     my ( $self, $key ) = @_;
@@ -469,48 +248,6 @@ sub get_acl {
     return $response->content;
 }
 
-=head2 set_acl
-
-Takes a configuration hash_ref containing:
-
-=over
-
-=item acl_xml (cannot be used in conjuction with acl_short)
-
-An XML string which contains access control information which matches
-Amazon's published schema.  There is an example of one of these XML strings
-in the tests for this module.
-
-=item acl_short (cannot be used in conjuction with acl_xml)
-
-You can use the shorthand notation instead of specifying XML for
-certain 'canned' types of acls.
-
-(from the Amazon API documentation)
-
-private: Owner gets FULL_CONTROL. No one else has any access rights.
-This is the default.
-
-public-read:Owner gets FULL_CONTROL and the anonymous principal is granted
-READ access. If this policy is used on an object, it can be read from a
-browser with no authentication.
-
-public-read-write:Owner gets FULL_CONTROL, the anonymous principal is
-granted READ and WRITE access. This is a useful policy to apply to a bucket,
-if you intend for any anonymous user to PUT objects into the bucket.
-
-authenticated-read:Owner gets FULL_CONTROL, and any principal authenticated
-as a registered Amazon S3 user is granted READ access.
-
-=item key (optional)
-
-If the key is not set, it will apply the acl to the bucket.
-
-=back
-
-Returns a boolean.
-
-=cut
 
 sub set_acl {
     my ( $self, $conf ) = @_;
@@ -540,12 +277,6 @@ sub set_acl {
 
 }
 
-=head2 get_location_constraint
-
-Retrieves the location constraint set when the bucket was created. Returns a
-string (eg, 'EU'), or undef if no location constraint was set.
-
-=cut
 
 sub get_location_constraint {
     my ($self) = @_;
@@ -567,19 +298,9 @@ sub get_location_constraint {
 
 # proxy up the err requests
 
-=head2 err
-
-The S3 error code for the last error the object ran into
-
-=cut
 
 sub err { $_[0]->account->err }
 
-=head2 errstr
-
-A human readable error string for the last error the object ran into
-
-=cut
 
 sub errstr { $_[0]->account->errstr }
 
@@ -629,7 +350,294 @@ sub _content_sub {
 
 __END__
 
+=pod
+
+=head1 NAME
+
+Net::Amazon::S3::Bucket - convenience object for working with Amazon S3 buckets
+
+=head1 VERSION
+
+version 0.57
+
+=head1 SYNOPSIS
+
+  use Net::Amazon::S3;
+
+  my $bucket = $s3->bucket("foo");
+
+  ok($bucket->add_key("key", "data"));
+  ok($bucket->add_key("key", "data", {
+     content_type => "text/html",
+    'x-amz-meta-colour' => 'orange',
+  }));
+
+  # the err and errstr methods just proxy up to the Net::Amazon::S3's
+  # objects err/errstr methods.
+  $bucket->add_key("bar", "baz") or
+      die $bucket->err . $bucket->errstr;
+
+  # fetch a key
+  $val = $bucket->get_key("key");
+  is( $val->{value},               'data' );
+  is( $val->{content_type},        'text/html' );
+  is( $val->{etag},                'b9ece18c950afbfa6b0fdbfa4ff731d3' );
+  is( $val->{'x-amz-meta-colour'}, 'orange' );
+
+  # returns undef on missing or on error (check $bucket->err)
+  is(undef, $bucket->get_key("non-existing-key"));
+  die $bucket->errstr if $bucket->err;
+
+  # fetch a key's metadata
+  $val = $bucket->head_key("key");
+  is( $val->{value},               '' );
+  is( $val->{content_type},        'text/html' );
+  is( $val->{etag},                'b9ece18c950afbfa6b0fdbfa4ff731d3' );
+  is( $val->{'x-amz-meta-colour'}, 'orange' );
+
+  # delete a key
+  ok($bucket->delete_key($key_name));
+  ok(! $bucket->delete_key("non-exist-key"));
+
+  # delete the entire bucket (Amazon requires it first be empty)
+  $bucket->delete_bucket;
+
+=head1 DESCRIPTION
+
+This module represents an S3 bucket.  You get a bucket object
+from the Net::Amazon::S3 object.
+
+=for test_synopsis no strict 'vars'
+
+=head1 METHODS
+
+=head2 new
+
+Create a new bucket object. Expects a hash containing these two arguments:
+
+=over
+
+=item bucket
+
+=item account
+
+=back
+
+=head2 add_key
+
+Takes three positional parameters:
+
+=over
+
+=item key
+
+=item value
+
+=item configuration
+
+A hash of configuration data for this key. (See synopsis);
+
+=back
+
+Returns a boolean.
+
+=head2 add_key_filename
+
+Use this to upload a large file to S3. Takes three positional parameters:
+
+=over
+
+=item key
+
+=item filename
+
+=item configuration
+
+A hash of configuration data for this key. (See synopsis);
+
+=back
+
+Returns a boolean.
+
+=head2 copy_key
+
+Creates (or replaces) a key, copying its contents from another key elsewhere in S3.
+Takes the following parameters:
+
+=over
+
+=item key
+
+The key to (over)write
+
+=item source
+
+Where to copy the key from. Should be in the form C</I<bucketname>/I<keyname>>/.
+
+=item conf
+
+Optional configuration hash. If present and defined, the configuration (ACL
+and headers) there will be used for the new key; otherwise it will be copied
+from the source key.
+
+=back
+
+=head2 edit_metadata
+
+Changes the metadata associated with an existing key. Arguments:
+
+=over
+
+=item key
+
+The key to edit
+
+=item conf
+
+The new configuration hash to use
+
+=back
+
+=head2 head_key KEY
+
+Takes the name of a key in this bucket and returns its configuration hash
+
+=head2 get_key $key_name [$method]
+
+Takes a key name and an optional HTTP method (which defaults to C<GET>.
+Fetches the key from AWS.
+
+On failure:
+
+Returns undef on missing content, throws an exception (dies) on server errors.
+
+On success:
+
+Returns a hashref of { content_type, etag, value, @meta } on success. Other
+values from the server are there too, with the key being lowercased.
+
+=head2 get_key_filename $key_name $method $filename
+
+Use this to download large files from S3. Takes a key name and an optional
+HTTP method (which defaults to C<GET>. Fetches the key from AWS and writes
+it to the filename. THe value returned will be empty.
+
+On failure:
+
+Returns undef on missing content, throws an exception (dies) on server errors.
+
+On success:
+
+Returns a hashref of { content_type, etag, value, @meta } on success
+
+=head2 delete_key $key_name
+
+Removes C<$key> from the bucket. Forever. It's gone after this.
+
+Returns true on success and false on failure
+
+=head2 delete_bucket
+
+Delete the current bucket object from the server. Takes no arguments.
+
+Fails if the bucket has anything in it.
+
+This is an alias for C<< $s3->delete_bucket($bucket) >>
+
+=head2 list
+
+List all keys in this bucket.
+
+see L<Net::Amazon::S3/list_bucket> for documentation of this method.
+
+=head2 list_all
+
+List all keys in this bucket without having to worry about
+'marker'. This may make multiple requests to S3 under the hood.
+
+see L<Net::Amazon::S3/list_bucket_all> for documentation of this method.
+
+=head2 get_acl
+
+Takes one optional positional parameter
+
+=over
+
+=item key (optional)
+
+If no key is specified, it returns the acl for the bucket.
+
+=back
+
+Returns an acl in XML format.
+
+=head2 set_acl
+
+Takes a configuration hash_ref containing:
+
+=over
+
+=item acl_xml (cannot be used in conjunction with acl_short)
+
+An XML string which contains access control information which matches
+Amazon's published schema.  There is an example of one of these XML strings
+in the tests for this module.
+
+=item acl_short (cannot be used in conjunction with acl_xml)
+
+You can use the shorthand notation instead of specifying XML for
+certain 'canned' types of acls.
+
+(from the Amazon API documentation)
+
+private: Owner gets FULL_CONTROL. No one else has any access rights.
+This is the default.
+
+public-read:Owner gets FULL_CONTROL and the anonymous principal is granted
+READ access. If this policy is used on an object, it can be read from a
+browser with no authentication.
+
+public-read-write:Owner gets FULL_CONTROL, the anonymous principal is
+granted READ and WRITE access. This is a useful policy to apply to a bucket,
+if you intend for any anonymous user to PUT objects into the bucket.
+
+authenticated-read:Owner gets FULL_CONTROL, and any principal authenticated
+as a registered Amazon S3 user is granted READ access.
+
+=item key (optional)
+
+If the key is not set, it will apply the acl to the bucket.
+
+=back
+
+Returns a boolean.
+
+=head2 get_location_constraint
+
+Retrieves the location constraint set when the bucket was created. Returns a
+string (eg, 'EU'), or undef if no location constraint was set.
+
+=head2 err
+
+The S3 error code for the last error the object ran into
+
+=head2 errstr
+
+A human readable error string for the last error the object ran into
+
 =head1 SEE ALSO
 
 L<Net::Amazon::S3>
 
+=head1 AUTHOR
+
+Pedro Figueiredo <me@pedrofigueiredo.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
