@@ -1,9 +1,14 @@
 package Net::Amazon::S3::Client;
+{
+  $Net::Amazon::S3::Client::VERSION = '0.57';
+}
 use Moose 0.85;
 use HTTP::Status qw(is_error status_message);
 use MooseX::StrictConstructor 0.16;
 use Moose::Util::TypeConstraints;
 
+# ABSTRACT: An easy-to-use Amazon S3 client
+
 type 'Etag' => where { $_ =~ /^[a-z0-9]{32}$/ };
 
 type 'OwnerId' => where { $_ =~ /^[a-z0-9]{64}$/ };
@@ -125,10 +130,16 @@ sub _send_request_xpc {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Net::Amazon::S3::Client - An easy-to-use Amazon S3 client
 
+=head1 VERSION
+
+version 0.57
+
 =head1 SYNOPSIS
 
   my $s3 = Net::Amazon::S3->new(
@@ -161,8 +172,8 @@ Net::Amazon::S3::Client - An easy-to-use Amazon S3 client
 
 The L<Net::Amazon::S3> module was written when the Amazon S3 service
 had just come out and it is a light wrapper around the APIs. Some
-bad API decisions were also made. The 
-L<Net::Amazon::S3::Client>, L<Net::Amazon::S3::Client::Bucket> and 
+bad API decisions were also made. The
+L<Net::Amazon::S3::Client>, L<Net::Amazon::S3::Client::Bucket> and
 L<Net::Amazon::S3::Client::Object> classes are designed after years
 of usage to be easy to use for common tasks.
 
@@ -173,6 +184,8 @@ to S3 and check the resultant ETag.
 WARNING: This is an early release of the Client classes, the APIs
 may change.
 
+=for test_synopsis no strict 'vars'
+
 =head1 METHODS
 
 =head2 buckets
@@ -200,3 +213,15 @@ may change.
   # returns a L<Net::Amazon::S3::Client::Bucket> object
   my $bucket = $client->bucket( name => $bucket_name );
 
+=head1 AUTHOR
+
+Pedro Figueiredo <me@pedrofigueiredo.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
