@@ -1,4 +1,7 @@
 package Net::Amazon::S3::HTTPRequest;
+{
+  $Net::Amazon::S3::HTTPRequest::VERSION = '0.57';
+}
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use HTTP::Date;
@@ -7,6 +10,8 @@ use Moose::Util::TypeConstraints;
 use URI::Escape qw( uri_escape_utf8 );
 use URI::QueryParam;
 
+# ABSTRACT: Create a signed HTTP::Request
+
 my $METADATA_PREFIX      = 'x-amz-meta-';
 my $AMAZON_HEADER_PREFIX = 'x-amz-';
 
@@ -219,10 +224,16 @@ sub _urlencode {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Net::Amazon::S3::HTTPRequest - Create a signed HTTP::Request
 
+=head1 VERSION
+
+version 0.57
+
 =head1 SYNOPSIS
 
   my $http_request = Net::Amazon::S3::HTTPRequest->new(
@@ -238,6 +249,8 @@ Net::Amazon::S3::HTTPRequest - Create a signed HTTP::Request
 This module creates an HTTP::Request object that is signed
 appropriately for Amazon S3.
 
+=for test_synopsis no strict 'vars'
+
 =head1 METHODS
 
 =head2 http_request
@@ -248,3 +261,16 @@ This method creates, signs and returns a HTTP::Request object.
 
 This method creates, signs and returns a query string authentication
 URI.
+
+=head1 AUTHOR
+
+Pedro Figueiredo <me@pedrofigueiredo.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
