@@ -1,7 +1,12 @@
 package Net::Amazon::S3::Request::CreateBucket;
+{
+  $Net::Amazon::S3::Request::CreateBucket::VERSION = '0.57';
+}
 use Moose 0.85;
 extends 'Net::Amazon::S3::Request';
 
+# ABSTRACT: An internal class to create a bucket
+
 has 'bucket'    => ( is => 'ro', isa => 'BucketName',      required => 1 );
 has 'acl_short' => ( is => 'ro', isa => 'Maybe[AclShort]', required => 0 );
 has 'location_constraint' =>
@@ -40,10 +45,16 @@ sub http_request {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Net::Amazon::S3::Request::CreateBucket - An internal class to create a bucket
 
+=head1 VERSION
+
+version 0.57
+
 =head1 SYNOPSIS
 
   my $http_request = Net::Amazon::S3::Request::CreateBucket->new(
@@ -57,9 +68,23 @@ Net::Amazon::S3::Request::CreateBucket - An internal class to create a bucket
 
 This module creates a bucket.
 
+=for test_synopsis no strict 'vars'
+
 =head1 METHODS
 
 =head2 http_request
 
 This method returns a HTTP::Request object.
 
+=head1 AUTHOR
+
+Pedro Figueiredo <me@pedrofigueiredo.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
