@@ -1,8 +1,13 @@
 package Net::Amazon::S3::Request::GetBucketAccessControl;
+{
+  $Net::Amazon::S3::Request::GetBucketAccessControl::VERSION = '0.57';
+}
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request';
 
+# ABSTRACT: An internal class to get a bucket's access control
+
 has 'bucket' => ( is => 'ro', isa => 'BucketName', required => 1 );
 
 __PACKAGE__->meta->make_immutable;
@@ -21,10 +26,16 @@ sub http_request {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Net::Amazon::S3::Request::GetBucketAccessControl - An internal class to get a bucket's access control
 
+=head1 VERSION
+
+version 0.57
+
 =head1 SYNOPSIS
 
   my $http_request = Net::Amazon::S3::Request::GetBucketAccessControl->new(
@@ -36,9 +47,23 @@ Net::Amazon::S3::Request::GetBucketAccessControl - An internal class to get a bu
 
 This module gets a bucket's access control.
 
+=for test_synopsis no strict 'vars'
+
 =head1 METHODS
 
 =head2 http_request
 
 This method returns a HTTP::Request object.
 
+=head1 AUTHOR
+
+Pedro Figueiredo <me@pedrofigueiredo.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
