@@ -1,4 +1,7 @@
 package Net::Amazon::S3::Request::GetObject;
+{
+  $Net::Amazon::S3::Request::GetObject::VERSION = '0.57';
+}
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 extends 'Net::Amazon::S3::Request';
@@ -7,6 +10,8 @@ has 'bucket' => ( is => 'ro', isa => 'BucketName', required => 1 );
 has 'key'    => ( is => 'ro', isa => 'Str',        required => 1 );
 has 'method' => ( is => 'ro', isa => 'HTTPMethod', required => 1 );
 
+# ABSTRACT: An internal class to get an object
+
 __PACKAGE__->meta->make_immutable;
 
 sub http_request {
@@ -33,10 +38,16 @@ sub query_string_authentication_uri {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Net::Amazon::S3::Request::GetObject - An internal class to get an object
 
+=head1 VERSION
+
+version 0.57
+
 =head1 SYNOPSIS
 
   my $http_request = Net::Amazon::S3::Request::GetObject->new(
@@ -50,6 +61,8 @@ Net::Amazon::S3::Request::GetObject - An internal class to get an object
 
 This module gets an object.
 
+=for test_synopsis no strict 'vars'
+
 =head1 METHODS
 
 =head2 http_request
@@ -60,3 +73,15 @@ This method returns a HTTP::Request object.
 
 This method returns query string authentication URI.
 
+=head1 AUTHOR
+
+Pedro Figueiredo <me@pedrofigueiredo.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
