@@ -1,9 +1,14 @@
 package Net::Amazon::S3::Request::ListBucket;
+{
+  $Net::Amazon::S3::Request::ListBucket::VERSION = '0.57';
+}
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
 use URI::Escape qw(uri_escape_utf8);
 extends 'Net::Amazon::S3::Request';
 
+# ABSTRACT: An internal class to list a bucket
+
 has 'bucket'    => ( is => 'ro', isa => 'BucketName', required => 1 );
 has 'prefix'    => ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
 has 'delimiter' => ( is => 'ro', isa => 'Maybe[Str]', required => 0 );
@@ -46,10 +51,16 @@ sub _urlencode {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Net::Amazon::S3::Request::ListBucket - An internal class to list a bucket
 
+=head1 VERSION
+
+version 0.57
+
 =head1 SYNOPSIS
 
   my $http_request = Net::Amazon::S3::Request::ListBucket->new(
@@ -64,9 +75,23 @@ Net::Amazon::S3::Request::ListBucket - An internal class to list a bucket
 
 This module lists a bucket.
 
+=for test_synopsis no strict 'vars'
+
 =head1 METHODS
 
 =head2 http_request
 
 This method returns a HTTP::Request object.
 
+=head1 AUTHOR
+
+Pedro Figueiredo <me@pedrofigueiredo.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Amazon Digital Services, Leon Brocard, Brad Fitzpatrick, Pedro Figueiredo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
